# 🚀 pt_dev_utils

[![PyPI version](https://img.shields.io/pypi/v/pt-dev-utils.svg)](https://pypi.org/project/pt-dev-utils/)
[![Python](https://img.shields.io/pypi/pyversions/pt-dev-utils.svg)](https://pypi.org/project/pt-dev-utils/)
[![License](https://img.shields.io/badge/license-Internal%20Use%20Only-blue.svg)](https://github.com/smitjethwa/pt_dev_utility)

**pt_dev_utils** is a lightweight internal Python utility package crafted to streamline backend development in the PT system. It includes modular, reusable functions that help keep your codebase **clean**, **efficient**, and **DRY**.

> 🔧 Built for internal use — optimized for speed, clarity, and team productivity.

---

## ✨ Features

- 📂 **File Utilities**: Standardized file operations (read, write, path handling)
- 📋 **Validation Functions**: Common data validators for backend pipelines
- 💡 **Minimal Dependencies**: Designed to stay lean and fast

---

## 📦 Installation

Install from PyPI using pip:

```bash
pip install pt-dev-utils
```

---

## ✅ Example Usage

```python
from pt_dev_utils import load_csv_as_records, read_csv_as_dict_list

records = load_csv_as_records('data/sample.csv')
print(records)
# [('John', 25, 'Engineer'), ('Jane', 30, 'Manager')]

# Read all columns with default headers
data = read_csv_as_dict_list('data.csv')

# Read with selected columns
data = read_csv_as_dict_list(
        'data.csv',
        selected_columns=['name', 'age']
    )


# Read with custom headers
data = read_csv_as_dict_list(
        'data.csv',
        custom_headers=['name', 'age', 'city']
    )

```
---


## 📚 Documentation

📖 [Read full documentation](https://pt-dev-utils.web.app)  
📦 [View on PyPI](https://pypi.org/project/pt-dev-utils/)  
📂 [GitHub Repository](https://github.com/smitjethwa/pt_dev_utility)

---

## 🧾 Changelog

### v1.1.8
- Added publishable docs
- Minor bug fixes

---

## 🛠 Contributing

This package is primarily maintained for internal use. For suggestions or bug reports, please open an issue on the [GitHub repo](https://github.com/smitjethwa/pt_dev_utility/issues).

---

## 🔐 License

**Internal Use Only** – All rights reserved © PT System.