"""PT Dev Utility package for time operations, notifications, and decorators.

This package provides utilities for Python 3.8+ development use.

Modules:
    notifications: Telegram messaging utilities
    pt_decorators: Function timing and performance decorators
    pt_time: Date and timestamp manipulation functions
    pt_csv: CSV data processing utilities
    fake_sql: CSV-to-SQL-like data conversion utilities

Example:
    >>> from pt_dev_utility import send_telegram_message
    >>> from pt_dev_utility import measure_execution_time
"""

from typing import List

# Import main functions with updated names
from .notifications import send_telegram_message
from .pt_decorators import measure_execution_time
from .pt_time import (
    get_current_date_components,
    get_current_timestamp,
    get_month_year_string,
    get_iso_timestamp_ist
)
from .pt_csv import read_csv_as_dict_list
from .fake_sql import load_csv_as_records

__version__: str = '1.1.6'
__author__: str = 'PT Dev Team'

# Public API - recommended functions
__all__: List[str] = [
    'send_telegram_message',
    'measure_execution_time',
    'get_current_date_components',
    'get_current_timestamp',
    'get_month_year_string',
    'get_iso_timestamp_ist',
    'read_csv_as_dict_list',
    'load_csv_as_records',
]
